==> leanix-dropkit-2.0.2-sources.jar: net/leanix/dropkit/oauth/OAuth2Authenticator.java <==
package net.leanix.dropkit.oauth;

import io.dropwizard.auth.AuthenticationException;
import io.dropwizard.auth.Authenticator;
import io.jsonwebtoken.ExpiredJwtException;
import io.jsonwebtoken.JwtException;
import java.util.Optional;
import javax.inject.Inject;
import javax.inject.Singleton;
import net.leanix.dropkit.oauth.models.User;
import net.leanix.dropkit.oauth.token.OAuth2Token;
import net.leanix.dropkit.oauth.token.OAuth2TokenConfig;
import net.leanix.dropkit.oauth.token.OAuth2TokenParser;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Authenticator used to protect resources.
 *
 *
 */
@Singleton
public class OAuth2Authenticator<U extends User> implements Authenticator<String, U> {
    private final Logger logger = LoggerFactory.getLogger(OAuth2Authenticator.class);
    private final OAuth2TokenParser parser;
    private final Class<U> userClass;

    @Inject
    public OAuth2Authenticator(OAuth2TokenConfig config, Class<U> userClass) {
        try {
            this.parser = new OAuth2TokenParser(config);
            this.userClass = userClass;
        } catch (Exception e) {
            throw new RuntimeException("unhandleable exception", e);
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.yammer.dropwizard.auth.Authenticator#authenticate(java.lang.Object)
     */
    @Override
    public Optional<U> authenticate(String accessToken) throws AuthenticationException {

        if (accessToken == null) {
            logger.warn("No token provided");
            return Optional.empty();
        }

        try {
            OAuth2Token<U> token = this.parser.parse(accessToken, userClass);
            return Optional.ofNullable(token.getPrincipal());
        } catch (ExpiredJwtException ex) {
            logger.warn("Token expired");
            return Optional.empty();
        } catch (JwtException ex) {
            logger.warn("Unable to verify token");
            return Optional.empty();
        } catch (Throwable ex) {
            throw new AuthenticationException("Unable to authenticate token", ex);
        }
    }
}

==> leanix-dropkit-2.0.6-sources.jar: net/leanix/dropkit/oauth/OAuth2Authenticator.java <==
package net.leanix.dropkit.oauth;

import io.dropwizard.auth.AuthenticationException;
import io.dropwizard.auth.Authenticator;
import io.jsonwebtoken.ExpiredJwtException;
import io.jsonwebtoken.JwtException;
import java.util.Optional;
import javax.inject.Inject;
import javax.inject.Singleton;
import net.leanix.dropkit.oauth.models.User;
import net.leanix.dropkit.oauth.token.OAuth2Token;
import net.leanix.dropkit.oauth.token.OAuth2TokenConfig;
import net.leanix.dropkit.oauth.token.OAuth2TokenParser;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Authenticator used to protect resources.
 *
 *
 */
@Singleton
public class OAuth2Authenticator<U extends User> implements Authenticator<String, U> {
    private final Logger logger = LoggerFactory.getLogger(OAuth2Authenticator.class);
    private final OAuth2TokenParser parser;
    private final Class<U> userClass;

    @Inject
    public OAuth2Authenticator(OAuth2TokenConfig config, Class<U> userClass) {
        try {
            this.parser = new OAuth2TokenParser(config);
            this.userClass = userClass;
        } catch (Exception e) {
            throw new RuntimeException("unhandleable exception", e);
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.yammer.dropwizard.auth.Authenticator#authenticate(java.lang.Object)
     */
    @Override
    public Optional<U> authenticate(String accessToken) throws AuthenticationException {

        if (accessToken == null) {
            logger.warn("No token provided");
            return Optional.empty();
        }

        try {
            OAuth2Token<U> token = this.parser.parse(accessToken, userClass);
            return Optional.ofNullable(token.getPrincipal());
        } catch (ExpiredJwtException ex) {
            logger.warn("Token expired");
            return Optional.empty();
        } catch (JwtException ex) {
            logger.warn("Unable to verify token: ", ex);
            return Optional.empty();
        } catch (Throwable ex) {
            throw new AuthenticationException("Unable to authenticate token", ex);
        }
    }
}
